@@ -75,7 +75,7 @@ void send_string( Display *d, char *thing_in ) {
   i = 0;
   while( ( thing[ i ] != L'\0' ) && ( i < CMD_STRING_MAXLEN ) ) {
     wc_singlechar_str[ 0 ] = thing[ i ];
-    dmsg( 1, "Sending key '%ls' (keysym=%lld)\n", 
+    dmsg( 1, "Sending key '%lc' (keysym=%lld)\n", 
         wc_singlechar_str[ 0 ], 
         (long long int)wc_singlechar_str[ 0 ] );
 
@@ -88,6 +88,9 @@ void send_string( Display *d, char *thing_in ) {
       wrap_key = key_modifiers[ keysym_to_modifier_map[ keysym ] ];
       keycode = keysym_to_keycode_map[keysym];
 
+      dmsg( 1, "Keycode: %d\n",
+        keycode );
+
       if( wrap_key != NULL )
           XTestFakeKeyEvent( d, thing_to_keycode( d, wrap_key ), True, CurrentTime );
       XTestFakeKeyEvent( d, keycode, True, CurrentTime );
@@ -194,6 +197,7 @@ void load_keycodes( Display *d ) {
     (KeyCode)min_keycode, max_keycode + 1 - min_keycode,
     &keysyms_per_keycode );
 
+  /* Clear tables */
   for( keysym=0; keysym<MAX_KEYSYM; keysym++ ) {
     keysym_to_modifier_map[keysym]=-1;
     keysym_to_keycode_map[keysym]=0;
@@ -210,10 +214,14 @@ void load_keycodes( Display *d ) {
       str = XKeysymToString( keysyms[ keycode_index * keysyms_per_keycode + wrap_key_index ] );
       if( str != NULL ) {
         keysym = XStringToKeysym( str );
-        keycode = XKeysymToKeycode( d, keysym );
-        //printf("i=%d (keysym %lld), j=%d (keycode %d): %s\n",keycode_index,(long long int)keysym,wrap_key_index,keycode,str);
+        /* keycode = XKeysymToKeycode( d, keysym ); */
+        keycode = keycode_index + min_keycode;
+        dmsg( 2, "i=%d (keysym %lld), j=%d (keycode %d): %s\n",
+            keycode_index, (long long int)keysym,
+            wrap_key_index, keycode, str );
 
-        if( ( keysym < MAX_KEYSYM ) && ( keysym_to_modifier_map[ keysym ] == -1 ) ) {
+        if( keysym < MAX_KEYSYM &&
+            keysym_to_modifier_map[ keysym ] == -1 ) {
           keysym_to_modifier_map[ keysym ] = wrap_key_index;
           keysym_to_keycode_map[ keysym ] = keycode;
         }
